<?php
/*
Plugin Name: Fun with Microformat Pingbacks
Plugin URI: http://www.wp-fun.co.uk/fun-with-microformat-pingbacks/
Description: Parses pingback URLs for hReview Microformats
Author: Andrew Rickmann
Version: 0.1
Author URI: http://www.wp-fun.co.uk
Generated At: www.wp-fun.co.uk;

*/ 

/*  Copyright 2008  Andrew Rickmann  (email : PLUGIN AUTHOR EMAIL)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if (!class_exists('fun_with_pingback_microformats')) {
    class fun_with_pingback_microformats	{
		
		/**
		* @var string   The name the options are saved under in the database.
		*/
		var $adminOptionsName = "fun_with_pingback_microformats_options";
	
		/**
		* PHP 5 Constructor
		*/		
		function __construct(){

			$this->adminOptions = $this->getAdminOptions();
		
			//*****************************************************************************************
			// These lines allow the plugin to be translated into different languages
			// You will need to create the appropriate language files
			// this assumes your language files will be in the format: fun_with_microformat_pingbacks-locationcode.mo
			// This also assumes your text domain will be: fun_with_microformat_pingbacks 
			// For more info: http://codex.wordpress.org/Translating_WordPress
			//*****************************************************************************************
			$fun_with_microformat_pingbacks_locale = get_locale();
			$fun_with_microformat_pingbacks_mofile = dirname(__FILE__) . "/languages/fun_with_microformat_pingbacks-".$fun_with_microformat_pingbacks_locale.".mo";
			load_textdomain("fun_with_microformat_pingbacks", $fun_with_microformat_pingbacks_mofile);
			
			add_action( 'comment_post' , array( &$this , 'parse_pingback' ) );
			add_action( 'admin_menu' , array(&$this , 'add_options_menu'));
						
		}
		
		/*
		 * 
		 */
		function add_options_menu(){
			add_submenu_page('options-general.php', 'Fun with Microformat Pingback Options', 'MF Pings', 10, __FILE__, array(&$this,'output_options_page'));
		}
		
		/**
		 * Outputs the options page and deals with any settings
		 * 
		 */
		function output_options_page(){
			
			//process results
			if ( isset( $_POST['ignore_non_mf']  ) && is_numeric( $_POST['ignore_non_mf'])){
				$this->adminOptions['ignore_non_mf'] =  ( $_POST['ignore_non_mf'] == 1 ) ? true  : false ;
			}
			
			if ( isset( $_POST['make_full_comment']  ) && is_numeric( $_POST['make_full_comment'])){
				$this->adminOptions['make_full_comment'] =  ( $_POST['make_full_comment'] == 1 ) ? true  : false ;
			}
			
			if ( isset( $_POST['ignore_non_mf'] ) || isset( $_POST['ignore_non_mf'] ) ){
				$this->saveAdminOptions();
			}
			
			
			//controlls
			?>
			<div class="wrap">
			<h2><?php _e( 'Microformat Ping Options' , 'fun_with_microformat_pingbacks' ); ?></h2>	
			<form method="post"> 
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row"><?php _e('Non-Microformat Pings' , 'fun_with_microformat_pingbacks'); ?></th>
						<td>
							<label for="ignore_non_mf">
							<?php _e('Do you want to ignore pingbacks from sites not using hReviews?' , 'fun_with_microformat_pingbacks'); ?>
							</label>
							<select name="ignore_non_mf" id="ignore_non_mf">
								<option value="0" <?php echo ( $this->adminOptions['ignore_non_mf'] ) ? 'selected="selected"' : '';  ?>><?php _e('No' , 'fun_with_microformat_pingbacks'); ?></option>
								<option value="1" <?php echo ( $this->adminOptions['ignore_non_mf'] ) ? 'selected="selected"' : '';  ?>><?php _e('Yes' , 'fun_with_microformat_pingbacks'); ?></option>	
							</select>
						</td>
					</tr>
					<tr>
						<th scope="row"><?php _e('Promote Pingbacks' , 'fun_with_microformat_pingbacks'); ?></th>
						<td>
							<label for="make_full_comment">
							<?php _e('Do you want to make microformat pings into normal comments?' , 'fun_with_microformat_pingbacks'); ?>
							</label>
							<select name="make_full_comment" id="make_full_comment">
								<option value="0" <?php echo ( $this->adminOptions['make_full_comment'] ) ? 'selected="selected"' : '';  ?>><?php _e('No' , 'fun_with_microformat_pingbacks'); ?></option>
								<option value="1" <?php echo ( $this->adminOptions['make_full_comment'] ) ? 'selected="selected"' : '';  ?>><?php _e('Yes' , 'fun_with_microformat_pingbacks'); ?></option>	
							</select>
						</td>
					</tr>					
				</tbody>
			</table>
			<p class="submit">
			<input type="submit" value="Save Changes" name="Submit"/>
			</p>	
			</form>
			</div>
			<?php
		}
			
		/**
		 * Parses the pinging site, updates, deletes or does nothing to the comment that has been saved.
		 */
		function parse_pingback($commentID){
					
			$commentdata = get_comment($commentID);
			
			//if this is not a pingback then bug out
			if ($commentdata->comment_type != 'pingback'){return $commentdata;}
			
			$reviews = $this->get_hreviews($commentdata->comment_author_url);
			
			$post_link = get_permalink( (int) $commentdata['comment_post_ID']);
			$relevent = 0;
			
			$newcommentdata = array();
			$newcommentdata['comment_ID'] = $commentID;
			
			foreach($reviews as $review){
				if ($review['item']['url'] == $post_link){
					if ( isset($review['summary']) ){
						
						//Filter the content
						$summary = apply_filters('pre_comment_content', $review['summary']);
						
						$newcommentdata['comment_content'] = $summary;
						$relevent++;
					}
				}
			}
			
			//if no relevent reviews and if the settings dictate it, delete the comment
			if ( $this->adminOptions['ignore_non_mf'] && $relevent < 1 ){
				wp_delete_comment($commentID);
			} 
			
			//if there are relevent hReviews
			if ( $relevent > 0 ) {
				if ( $this->adminOptions['make_full_comment'] ){
					$newcommentdata['comment_type'] = '';
				}
				wp_update_comment($newcommentdata);
			}
		}
		
		/**
		 * Processes the URL for hReviews using hKit
		 */
		function get_hreviews($url){
			
			include(dirname(__FILE__).'/hkit/hkit.class.php');
    		$hKit = new hKit;
    		$result = $hKit->getByURL('hreview', $url);
			return $result;
				
		}
		
		/**
		* Retrieves the options from the database.
		* @return array
		*/
		function getAdminOptions() {
		$adminOptions = array("ignore_non_mf" => false,
		"make_full_comment" => false,);
		$savedOptions = get_option($this->adminOptionsName);
		if (!empty($savedOptions)) {
			foreach ($savedOptions as $key => $option) {
				$adminOptions[$key] = $option;
			}
		}
		update_option($this->adminOptionsName, $adminOptions);
		return $adminOptions;
		}
		
		/**
		* Saves the admin options to the database.
		*/
		function saveAdminOptions(){
			update_option($this->adminOptionsName, $this->adminOptions);
		}
		

    }
	
}

//instantiate the class
if (class_exists('fun_with_pingback_microformats')) {
	$fun_with_pingback_microformats = new fun_with_pingback_microformats();
}




?>